function part=partitioner(md,varargin)
%PARTITIONER - partition mesh 
%
%   List of options to partitioner: 
%
%   package: 'chaco', 'metis' or 'scotch'
%   npart: number of partitions.
%   weighting: 'on' or 'off': default off
%   section:  1 by defaults(1=bisection, 2=quadrisection, 3=octasection)
%   
%   Usage:
%      md.part=partitioner(md,'package','chaco','npart',100,'weighting','on');
%


%get options: 
options=pairoptions(varargin{:});

%set defaults
options=addfielddefault(options,'package','chaco');
options=addfielddefault(options,'npart',10);
options=addfielddefault(options,'weighting','on');
options=addfielddefault(options,'section',1);

%get package: 
package=getfieldvalue(options,'package');
npart=getfieldvalue(options,'npart');

if strcmpi(package,'chaco'),

	%  default method (from chaco.m)
	method=[1 1 0 0 1 1 50 0 .001 7654321];
	method(1)=3;    %  global method (3=inertial (geometric))
	method(3)=1;    %  vertex weights (0=off, 1=on)
	
	%specify bisection
	method(6)=getfieldvalue(options,'section');%  ndims (1=bisection, 2=quadrisection, 3=octasection)

	%are we using weights? 
	if strcmpi(getfieldvalue(options,'weighting'),'on'),
	
		%  add integer scaled vertex weights into adjacency matrix for chaco (on diagonal)
		adj_mat2=md.adjacency+sparse(1:size(md.adjacency,1),1:size(md.adjacency,2),floor(md.vwgt/min(md.vwgt)));
	
		%  partition into nparts
		part=chaco(adj_mat2,[md.x md.y],method,npart)'; 
	else
		%  partition into nparts
		method(3)=0;    %  vertex weights (0=off, 1=on)
		part=chaco(md.adjacency,[md.x md.y],method,npart)'; 
	end
	part=part+1; %index partitions from 1 up. like metis.

elseif strcmpi(package,'scotch'),

	error(['partitioner error message: ''scotch'' partitioner not supported yet!']);

elseif strcmpi(package,'metis'),

	[element_partitioning,part]=MeshPartition(md,npart);

else

	error(['partitioner error message: could not find ' package ' partitioner']);
	help partitioner

end
